@@ -1,19 +1,26 @@
 
 from PyObjCTools.TestSupport import *
 from WebKit import *
-import Quartz
+
+try:
+    import Quartz
+except ImportError:
+    Quartz = None
 
 class TestCarbonUtils (TestCase):
     @onlyOn32Bit
     def testFunctions(self):
+        if Quartz is None:
+            self.fail("Quartz is not installed")
+
         WebInitForCarbon()
 
         img = NSImage.imageNamed_('NSHelpCursor')
-        self.failUnlessIsInstance(img, NSImage)
+        self.assertIsInstance(img, NSImage)
 
         ref = WebConvertNSImageToCGImageRef(img)
         if ref is not None:
-            self.failUnlessIsInstance(ref, Quartz.CGImageRef)
+            self.assertIsInstance(ref, Quartz.CGImageRef)
 
 if __name__ == "__main__":
     main()
